identify method
Associates a user identity with their actions and traits.
Use this to tie user actions to a recognizable userId.
userId - The unique identifier for the user.
traits - Optional user traits/attributes (name, email, plan, etc.).
options - Optional per-call options (custom context, integrations, etc.).
Implementation
void identify(String userId, {RudderTraits? traits, RudderOption? options}) {
throw UnimplementedError('identify(String userId, {RudderTraits? traits, '
'RudderOption? options}) has not been implemented.');
}