optOut method

void optOut(
  1. bool optOut
)

Controls whether the SDK should collect and send data.

Use this to respect user privacy preferences and comply with data protection regulations like GDPR.

optOut - True to stop collecting data, false to resume data collection.

Implementation

void optOut(bool optOut) {
  throw UnimplementedError('optOut(bool optOut) has not been implemented.');
}