startSession method

void startSession({
  1. int? sessionId,
})

Manually starts a new session with an optional custom session ID.

Use this to manually control session tracking. By default, the SDK automatically manages sessions, but you can use this method for custom session management.

sessionId - Optional custom session identifier. If not provided, a new session ID will be generated.

Implementation

void startSession({int? sessionId}) {
  throw UnimplementedError(
      'startSession({int? sessionId}) has not been implemented');
}