alias method
Creates an alias linking two user identities.
Use this when you want to merge two user identities.
newId - The new user identifier to alias to the current user.
options - Optional per-call options (custom context, integrations, etc.).
Implementation
void alias(String newId, {RudderOption? options}) {
throw UnimplementedError(
'alias(String newId, {RudderOption? options}) has not been implemented.');
}