reset method
Resets the user state and clears all user data.
Use this when a user logs out or you want to clear all stored user information.
clearAnonymousId - Whether to also clear the anonymous ID and generate a new one.
Implementation
void reset({bool clearAnonymousId = false}) {
throw UnimplementedError('reset() has not been implemented.');
}